==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/app/controllers/product_faq_controller.rb <==
# -*- coding: utf-8 -*-
class ProductFaqController < ApplicationController
  class_desc :display_name => "商品FAQ管理"

  #
  # = 検索画面表示アクション =
  #
  def index
    @condition = prepare_session_condition do |condition|
      condition || ProductFaq::SearchInfo.new(params[:condition])
    end
    if @condition.valid?
      per_page = @condition.disp_count ? @condition.disp_count.to_i : 20
      @product_faqs = ProductFaq.paginate(
        @condition.to_find_options(
          :page => params[:page], :per_page => per_page, :order => "product_faqs.created_at DESC"))
    end
  end

  #
  # = 詳細画面表示アクション =
  #
  def show
    @product_faq = ProductFaq.find(params[:id])
    @relation_product = @product_faq.relation_products
    @product_faq_displays = @product_faq.displays
  end

  #
  # = 新規登録画面表示アクション =
  #
  def new
    if flash[:product_faq]
      # バリデーションエラーからの戻りの場合
      @product_faq = flash[:product_faq]
      @invalid_product_faq_displays = flash[:invalid_product_faq_displays]
      @products = ProductFaqRelationProduct.create_product_list(@product_faq.relation_products)
    elsif params[:inquiry_id]
      # 問合せ情報詳細から遷移の場合、問合せ情報を反映
      inquiry = Inquiry.find(params[:inquiry_id])
      displays = []
      I18n.supported_locales.each do |locale|
        display = ProductFaqDisplay.new
        # 同じ言語のお問合せ情報をコピー
        if locale.to_s == inquiry.locale
          display.inquiry_user = inquiry.fullname
          display.inquiry = inquiry.inquiry
          display.answer = inquiry.answer
        end
        display.locale = locale.to_s
        displays << display
      end

      relation_products = []
      unless inquiry.inquiry_products.nil?
        inquiry.inquiry_products.each do |inquiry_product|
          pfrp = ProductFaqRelationProduct.new()
          pfrp.product_id = inquiry_product.product_id
          relation_products << pfrp
        end
      end

      @product_faq = ProductFaq.new
      @product_faq.answer_date_text = Date.today.strftime('%Y/%m/%d')
      @product_faq.displays = displays
      @products = ProductFaqRelationProduct.create_product_list(relation_products)
    else
      @product_faq = ProductFaq.new
      create_locales.each do |locale|
        @product_faq.displays.build(:locale => locale)
      end
      @product_faq.answer_date_text = Date.today.strftime('%Y/%m/%d')
      @products = ProductFaqRelationProduct.create_product_list(@product_faq.relation_products)
    end
  end

  #
  # = 編集画面表示アクション =
  #
  def edit
    if flash[:product_faq]
      # バリデーションエラーからの戻りの場合
      @product_faq = flash[:product_faq]
      @invalid_product_faq_displays = flash[:invalid_product_faq_displays]
      @products = ProductFaqRelationProduct.create_product_list(@product_faq.relation_products)
    else
      @product_faq = ProductFaq.find(params[:id])
      create_locales(@product_faq.displays).each do |locale|
        @product_faq.displays.build(:locale => locale)
      end
      @product_faq.answer_date_text = @product_faq.answer_date
      @products = ProductFaqRelationProduct.create_product_list(@product_faq.relation_products)
    end
  end

  #
  # = 商品Q&A更新アクション =
  #
  def update
    product_faq = ProductFaq.find(params[:id])
    # 商品選択で商品が選択された場合のみ、DBに保存されている商品関連データを削除します。
    product_faq.old_product_mark_for_destruction(params[:product_faq][:targets_modified])
    product_faq.attributes = params[:product_faq]
    valid_flg, error_for_locale = product_faq.validate_for_product_faq

    unless valid_flg
      flash[:product_faq] = product_faq
      flash[:invalid_product_faq_displays] = error_for_locale
      return redirect_to :action => :edit, :page => params[:page]
    end

    ProductFaq.transaction do
      # 未入力のdisplayを削除
      product_faq.displays = delete_instance_display(product_faq.displays)
      product_faq.answer_date = product_faq.answer_date_text
      product_faq.save!
    end
    redirect_to :action => :index, :page => params[:page]
  end

  #
  # = 商品Q&A登録アクション =
  #
  def create
    product_faq = ProductFaq.new(params[:product_faq])
    valid_flg, error_for_locale = product_faq.validate_for_product_faq

    unless valid_flg
      flash[:product_faq] = product_faq
      flash[:invalid_product_faq_displays] = error_for_locale
      return redirect_to :action => :new, :page => params[:page]
    end

    ProductFaq.transaction do
      # 未入力のdisplayを削除
      product_faq.displays = delete_instance_display(product_faq.displays)
      product_faq.answer_date = product_faq.answer_date_text
      product_faq.save!
    end
    redirect_to :action => :index, :page => params[:page]
  end

  #
  # = 編集画面表示アクション =
  #
  def destroy
    ProductFaq.destroy(params[:id])
    redirect_to :action => 'index', :page => params[:page]
  end

  private
  # 登録されていないロケールの配列を返します
  def create_locales(displays = [])
    create_locales = []
    I18n.supported_locales.each do |locale|
      create_locales << locale.to_s
    end

    displays.each do |display|
      create_locales.delete(display.locale)
    end
    return create_locales
  end

  # 登録されていない言語のインスタンスを削除します
  # 削除された後のProductFaqDisplayの配列を返します。
  def delete_instance_display(displays = [])
    new_displays = []
    displays.map.each do |display|
      unless (display.inquiry_user.empty? && display.inquiry.empty? && display.answer_user.empty? && display.answer.empty?)
        new_displays << display
      end
    end
    return new_displays
  end

end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/app/controllers/product_faq_controller.rb <==
# -*- coding: utf-8 -*-
class ProductFaqController < ApplicationController
  class_desc :display_name => "商品FAQ管理"

  #
  # = 検索画面表示アクション =
  #
  def index
    @condition = prepare_session_condition do |condition|
      condition || ProductFaq::SearchInfo.new(params[:condition])
    end
    if @condition.valid?
      per_page = @condition.disp_count ? @condition.disp_count.to_i : 20
      @product_faqs = ProductFaq.paginate(
        @condition.to_find_options(
          :page => params[:page], :per_page => per_page, :order => "product_faqs.created_at DESC"))
    end
  end

  #
  # = 詳細画面表示アクション =
  #
  def show
    @product_faq = ProductFaq.find(params[:id])
    @relation_product = @product_faq.relation_products
    @product_faq_displays = @product_faq.displays
  end

  #
  # = 新規登録画面表示アクション =
  #
  def new
    if flash[:product_faq]
      # バリデーションエラーからの戻りの場合
      @product_faq = flash[:product_faq]
      @invalid_product_faq_displays = flash[:invalid_product_faq_displays]
      @products = ProductFaqRelationProduct.create_product_list(@product_faq.relation_products)
    elsif params[:inquiry_id]
      @product_faq = ProductFaq.new(:answer_date_text => Date.today.strftime('%Y/%m/%d'))
      # 問合せ情報詳細から遷移の場合、問合せ情報を反映
      inquiry = Inquiry.find(params[:inquiry_id])
      I18n.supported_locales.each do |locale|
        # 同じ言語のお問合せ情報をコピー
        if locale.to_s == inquiry.locale
          @product_faq.displays << ProductFaqDisplay.new(
            :inquiry_user => inquiry.fullname,
            :inquiry => inquiry.inquiry,
            :answer => inquiry.answer,
            :locale => locale.to_s
          )
        else
          @product_faq.displays << ProductFaqDisplay.new(:locale => locale.to_s)
        end
      end

      # QA対象商品
      relation_products = []
      unless inquiry.inquiry_products.nil?
        inquiry.inquiry_products.each do |inquiry_product|
          relation_products << ProductFaqRelationProduct.new(:product_id => inquiry_product.product_id)
        end
      end
      @products = ProductFaqRelationProduct.create_product_list(relation_products)
      @product_faq.relation_products << relation_products
    else
      @product_faq = ProductFaq.new(:answer_date_text => Date.today.strftime('%Y/%m/%d'))
      create_locales.each do |locale|
        @product_faq.displays.build(:locale => locale)
      end
      @products = ProductFaqRelationProduct.create_product_list(@product_faq.relation_products)
    end
  end

  #
  # = 編集画面表示アクション =
  #
  def edit
    if flash[:product_faq]
      # バリデーションエラーからの戻りの場合
      @product_faq = flash[:product_faq]
      @invalid_product_faq_displays = flash[:invalid_product_faq_displays]
      @products = ProductFaqRelationProduct.create_product_list(@product_faq.relation_products)
    else
      @product_faq = ProductFaq.find(params[:id])
      create_locales(@product_faq.displays).each do |locale|
        @product_faq.displays.build(:locale => locale)
      end
      @product_faq.answer_date_text = @product_faq.answer_date
      @products = ProductFaqRelationProduct.create_product_list(@product_faq.relation_products)
    end
  end

  #
  # = 商品Q&A更新アクション =
  #
  def update
    product_faq = ProductFaq.find(params[:id])
    # 商品選択で商品が選択された場合のみ、DBに保存されている商品関連データを削除します。
    product_faq.old_product_mark_for_destruction(params[:product_faq][:targets_modified])
    product_faq.attributes = params[:product_faq]
    valid_flg, error_for_locale = product_faq.validate_for_product_faq

    unless valid_flg
      flash[:product_faq] = product_faq
      flash[:invalid_product_faq_displays] = error_for_locale
      return redirect_to :action => :edit, :page => params[:page]
    end

    ProductFaq.transaction do
      # 未入力のdisplayを削除
      product_faq.displays = delete_instance_display(product_faq.displays)
      product_faq.answer_date = product_faq.answer_date_text
      product_faq.save!
    end
    redirect_to :action => :index, :page => params[:page]
  end

  #
  # = 商品Q&A登録アクション =
  #
  def create
    product_faq = ProductFaq.new(params[:product_faq])
    valid_flg, error_for_locale = product_faq.validate_for_product_faq

    unless valid_flg
      flash[:product_faq] = product_faq
      flash[:invalid_product_faq_displays] = error_for_locale
      return redirect_to :action => :new, :page => params[:page]
    end

    ProductFaq.transaction do
      # 未入力のdisplayを削除
      product_faq.displays = delete_instance_display(product_faq.displays)
      product_faq.answer_date = product_faq.answer_date_text
      product_faq.save!
    end
    redirect_to :action => :index, :page => params[:page]
  end

  #
  # = 編集画面表示アクション =
  #
  def destroy
    ProductFaq.destroy(params[:id])
    redirect_to :action => 'index', :page => params[:page]
  end

  private
  # 登録されていないロケールの配列を返します
  def create_locales(displays = [])
    create_locales = []
    I18n.supported_locales.each do |locale|
      create_locales << locale.to_s
    end

    displays.each do |display|
      create_locales.delete(display.locale)
    end
    return create_locales
  end

  # 登録されていない言語のインスタンスを削除します
  # 削除された後のProductFaqDisplayの配列を返します。
  def delete_instance_display(displays = [])
    new_displays = []
    displays.map.each do |display|
      unless (display.inquiry_user.empty? && display.inquiry.empty? && display.answer_user.empty? && display.answer.empty?)
        new_displays << display
      end
    end
    return new_displays
  end

end
